==> vokoscreen_2.0.16~beta.orig.tar.gz: vokoscreen-2.0.16-beta/language/vokoscreen_it_IT.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it_IT" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>Spedisci via mail l&apos;ultimo video</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Spedisci via mail uno o più video selezionati</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Invia</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Troverete il video come allegato</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Selezionare uno o più file</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>is busy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Noborder</source>
        <translation>Senza bordi</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Bordi</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>schermo intero</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>finestre</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>area</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lente di ingrandimento</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predefinito</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Non registrare il cursore del mouse</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Ubicazione del video</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Riproduttore</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Minimizza Vokoscreen quando inizia la registrazione</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>inizio</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Riproduci</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Invia</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Durata della registrazione</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Dimensioni in KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Dimensioni dello schermo da registrare</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Impostazioni fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Apri cartella</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Conto alla rovescia</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Riproduci ultimo video</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Invia video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Selezionare una o più periferiche</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Fotogrammi al secondo attuale</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>Dispositivo %1 è occupato</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>inizio</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Pagina iniziale</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Mailinglist</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Assistenza</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Sviluppatore</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Fotogrammi</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>Beta openSUSE</translation>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation>Beta Ubuntu</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donate</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Programma per registrare</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduzioni</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Codice sorgente</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostra nella systray</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Nuova versione disponibile</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec video</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec audio</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Seleziona webcam</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.1.8~beta.orig.tar.gz: vokoscreen-2.1.8-beta/language/vokoscreen_it_IT.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it_IT" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>La periferica è occupata</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please install a videoplayer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Spedisci via mail l&apos;ultimo video</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Spedisci via mail uno o più video selezionati</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Invia</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Troverete il video come allegato</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Selezionare uno o più file</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Bordi</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>La periferica è occupata</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>schermo intero</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>finestre</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>area</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lente di ingrandimento</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predefinito</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Non registrare il cursore del mouse</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Ubicazione del video</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Riproduttore</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Minimizza Vokoscreen quando inizia la registrazione</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>inizio</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Riproduci</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Invia</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Durata della registrazione</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Dimensioni in KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Dimensioni dello schermo da registrare</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Impostazioni fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Apri cartella</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Conto alla rovescia</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Riproduci ultimo video</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Invia video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Selezionare una o più periferiche</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Fotogrammi al secondo attuale</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>inizio</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Pagina iniziale</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Mailinglist</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Assistenza</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Sviluppatore</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Fotogrammi</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donate</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Programma per registrare</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduzioni</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Codice sorgente</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostra nella systray</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Nuova versione disponibile</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec video</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec audio</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Seleziona webcam</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
